pub struct AbbayeConfig {
pub site: SiteConfig,
pub version_extractor: AnyVersionExtractor,
pub changelog: ChangelogConfig,
pub builders: Vec<AnyBuilder>,
pub output_dir: Option<PathBuf>,
}Expand description
A full configuration for the Abbaye site generator.
Here’s a sample configuration that works well as a starting point for rust projects:
[site]
name = "Abbaye"
[version_extractor]
type = "cargo" # extract version from Cargo.toml
[changelog]
# let's use the default changelog extractor
[[builders]]
type = "cargo" # calls `cargo build --release` for each target
targets = ["x86_64-unknown-linux-gnu", "x86_64-unknown-linux-musl"]
[[builders]]
type = "cargo_doc" # generates documentation using `cargo doc`
no_deps = true
[[builders]]
type = "archive" # creates a compressed tarball of the source codeYou can learn more about each builder type in the builders module documentation.
Fields
site: SiteConfigversion_extractor: AnyVersionExtractorchangelog: ChangelogConfigbuilders: Vec<AnyBuilder>output_dir: Option<PathBuf>Trait Implementations
Sourceimpl Debug for AbbayeConfig
impl Debug for AbbayeConfig
Sourceimpl<'de> Deserialize<'de> for AbbayeConfig
impl<'de> Deserialize<'de> for AbbayeConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,